<?php
/*
Plugin Name: CrossSync
Plugin URI: https://sukhofficial.info/crosssync/
Description: CrossSync | Allows user to sync post with multiple websites.
Version: 1.9
Author: Sukh Official
Author URI: https://sukhofficial.info/
Domain Path: /languages
Text Domain: crosssync
License: GPL2 or later 
*/

// plugin definitions 
define('crosssync_PLUGIN', '/crosssync/');

// directory define
define('crosssync_PLUGIN_DIR', WP_PLUGIN_DIR . crosssync_PLUGIN);
define('crosssync_INCLUDES_DIR', crosssync_PLUGIN_DIR . 'includes/');

define('crosssync_ASSETS_DIR', crosssync_PLUGIN_DIR . 'assets/');
define('crosssync_CSS_DIR', crosssync_ASSETS_DIR . 'css/');
define('crosssync_JS_DIR', crosssync_ASSETS_DIR . 'js/');
define('crosssync_IMAGES_DIR', crosssync_ASSETS_DIR . 'images/');

// URL define
define('crosssync_PLUGIN_URL', WP_PLUGIN_URL . crosssync_PLUGIN);

define('crosssync_ASSETS_URL', crosssync_PLUGIN_URL . 'assets/');
define('crosssync_IMAGES_URL', crosssync_ASSETS_URL . 'images/');
define('crosssync_CSS_URL', crosssync_ASSETS_URL . 'css/');
define('crosssync_JS_URL', crosssync_ASSETS_URL . 'js/');

// define text domain
define('crosssync_txt_domain', 'crosssync');

global $crosssync_version;
$crosssync_version = '1.6';

class CrossSync
{

	var $crosssync_setting = '';

	function __construct()
	{
		global $wpdb;

		$this->crosssync_setting = 'crosssync_setting';

		register_activation_hook(__FILE__,  array(&$this, 'crosssync_install'));

		register_deactivation_hook(__FILE__, array(&$this, 'crosssync_deactivation'));

		add_action('admin_menu', array($this, 'crosssync_add_menu'));

		add_action('admin_enqueue_scripts', array($this, 'crosssync_enqueue_scripts'));

		add_action('wp_enqueue_scripts', array($this, 'crosssync_front_enqueue_scripts'));

		add_action('plugins_loaded', array($this, 'crosssync_load_textdomain'));
	}

	function crosssync_load_textdomain()
	{
		load_plugin_textdomain(crosssync_txt_domain, false, basename(dirname(__FILE__)) . '/languages'); //Loads plugin text domain for the translation
		do_action('crosssync_txt_domain');
	}

	static function crosssync_install()
	{

		global $wpdb, $crosssync, $crosssync_version;

		$charset_collate = $wpdb->get_charset_collate();
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

		update_option("crosssync_plugin", true);
		update_option("crosssync_version", $crosssync_version);
	}

	static function crosssync_deactivation()
	{
		// deactivation process here
	}

	function crosssync_get_sub_menu()
	{
		$crosssync_admin_menu = array(
			array(
				'name' => __('Setting', 'crosssync'),
				'cap'  => 'manage_options',
				'slug' => $this->crosssync_setting,
			),
		);
		return $crosssync_admin_menu;
	}

	function crosssync_add_menu()
	{

		$crosssync_main_page_name = __('CrossSync', 'crosssync');
		$crosssync_main_page_capa = 'manage_options';
		$crosssync_main_page_slug = $this->crosssync_setting;

		$crosssync_get_sub_menu   = $this->crosssync_get_sub_menu();
		/* set capablity here.... Right now manage_options capability given to all page and sub pages. <span class="dashicons dashicons-money"></span>*/
		add_menu_page($crosssync_main_page_name, $crosssync_main_page_name, $crosssync_main_page_capa, $crosssync_main_page_slug, array(&$this, 'crosssync_route'), 'dashicons-update-alt', 11);

		foreach ($crosssync_get_sub_menu as $crosssync_menu_key => $crosssync_menu_value) {
			add_submenu_page(
				$crosssync_main_page_slug,
				$crosssync_menu_value['name'],
				$crosssync_menu_value['name'],
				$crosssync_menu_value['cap'],
				$crosssync_menu_value['slug'],
				array($this, 'crosssync_route')
			);
		}
	}

	function crosssync_is_activate()
	{
		if (get_option("crosssync_plugin")) {
			return true;
		} else {
			return false;
		}
	}

	function crosssync_admin_slugs()
	{
		$crosssync_pages_slug = array(
			$this->crosssync_setting,
		);
		return $crosssync_pages_slug;
	}

	function crosssync_is_page()
	{
		if (isset($_REQUEST['page']) && in_array($_REQUEST['page'], $this->crosssync_admin_slugs())) {
			return true;
		} else {
			return false;
		}
	}

	function crosssync_admin_msg($key)
	{
		$admin_msg = array(
			"crosssync_msg" => __("Enter message here", 'crosssync')
		);

		if ($key == 'script') {
			$script = '<script type="text/javascript">';
			$script .= 'var __crosssync_msg = ' . json_encode($admin_msg);
			$script .= '</script>';
			return $script;
		} else {
			return isset($admin_msg[$key]) ? $admin_msg[$key] : false;
		}
	}

	function crosssync_enqueue_scripts()
	{
		global $crosssync_version;
		/* must register style and than enqueue */
		if ($this->crosssync_is_page()) {
			/*********** register and enqueue styles ***************/
			wp_register_style('crosssync_admin_style_css',  crosssync_CSS_URL . 'crosssync_admin_style.css', false, $crosssync_version);
			wp_enqueue_style('crosssync_admin_style_css');


			/*********** register and enqueue scripts ***************/
			echo $this->crosssync_admin_msg('script');
			wp_register_script('crosssync_admin_js', crosssync_JS_URL . 'crosssync_admin_js.js', 'jQuery', $crosssync_version, true);
			wp_enqueue_script('jquery');
			wp_enqueue_script('crosssync_admin_js');
		}
	}

	function crosssync_front_enqueue_scripts()
	{
		global $crosssync_version;
		// need to check here if its front section than enqueue script
		// if( $ncm_template_loader->ncm_is_front_page() ) {
		/*********** register and enqueue styles ***************/

		wp_register_style(
			'crosssync_front_css',
			crosssync_CSS_URL . 'crosssync_front_style.css?rand=' . rand(1, 999),
			false,
			$crosssync_version
		);

		wp_enqueue_style('crosssync_front_css');


		/*********** register and enqueue scripts ***************/
		echo "<script> var ajaxurl = '" . admin_url('admin-ajax.php') . "'; </script>";

		wp_register_script(
			'crosssync_front_js',
			crosssync_JS_URL . 'crosssync_front_js.js?rand=' . rand(1, 999),
			'jQuery',
			$crosssync_version,
			true
		);

		wp_enqueue_script('jquery');
		wp_enqueue_script('crosssync_front_js');
		// }

	}

	function crosssync_route()
	{
		global $crosssync_settings;
		if (isset($_REQUEST['page']) && $_REQUEST['page'] != '') {
			switch ($_REQUEST['page']) {
				case $this->crosssync_setting:
					$crosssync_settings->crosssync_display_settings();
					break;
				default:
					_e("Product Listing will be here", 'crosssync');
					break;
			}
		}
	}

	function crosssync_write_log($content = '', $file_name = 'crosssync_log.txt')
	{
		$file = __DIR__ . '/log/' . $file_name;
		$file_content = "=============== Write At => " . date("y-m-d H:i:s") . " =============== \r\n";
		$file_content .= $content . "\r\n\r\n";
		file_put_contents($file, $file_content, FILE_APPEND | LOCK_EX);
	}
}


// begin!
global $crosssync;
$crosssync = new CrossSync();

if ($crosssync->crosssync_is_activate() && file_exists(crosssync_INCLUDES_DIR . "crosssync_settings.class.php")) {
	include_once(crosssync_INCLUDES_DIR . "crosssync_settings.class.php");
}

if ($crosssync->crosssync_is_activate() && file_exists(crosssync_INCLUDES_DIR . "crosssync_sync.class.php")) {
	include_once(crosssync_INCLUDES_DIR . "crosssync_sync.class.php");
}

if ($crosssync->crosssync_is_activate() && file_exists(crosssync_INCLUDES_DIR . "crosssync_post_meta.class.php")) {
	include_once(crosssync_INCLUDES_DIR . "crosssync_post_meta.class.php");
}
