<?php
if (!class_exists('crosssync_Settings')) {

    class crosssync_Settings
    {

        function __construct()
        {

            add_action("crosssync_save_settings", array($this, "crosssync_save_settings_func"), 10, 1);
        }

        function crosssync_display_settings()
        {
            if (file_exists(crosssync_INCLUDES_DIR . "crosssync_settings.view.php")) {
                include_once(crosssync_INCLUDES_DIR . "crosssync_settings.view.php");
            }
        }

        function crosssync_default_setting_option()
        {
            return array(
                'crosssync_host_name' => array('0' => ''),
                'crosssync_strict_mode' => array('0' => '1'),
                'crosssync_content_match' => array('0' => 'title'),
                'crosssync_content_username' => array('0' => ''),
                'crosssync_content_password' => array('0' => ''),
                'crosssync_selected' => array('0' => ''),
                'crosssync_roles_allowed' => array('0' => array('roles' => array('administrator' => 'on', 'editor' => 'on', 'author' => 'on')))
            );
        }

        function crosssync_save_settings_func($params = array())
        {
            $nonce = wp_create_nonce('crosssync_nonce');
            if (! isset($_POST['crosssync_general_option_field']) || ! wp_verify_nonce($_POST['crosssync_general_option_field'], 'crosssync_nonce')) {
                // Nonce verification failed; handle error or exit.
                wp_die('verification failed. Please try again');
            }

            if (isset($params['crosssync_setting']) && $params['crosssync_setting'] != '') {
                $crosssync_setting = $params['crosssync_setting'];
                unset($params['crosssync_setting']);
                unset($params['crosssync_setting_save']);

                if (isset($params['crosssync_host_name']) && !empty($params['crosssync_host_name'])) {
                    $hostnames = array();
                    $usernames = array();
                    $passwords = array();
                    foreach ($params['crosssync_host_name'] as $key => $hostname) {
                        $hostnames[] = sanitize_url($hostname);
                        $usernames[] = sanitize_user($params['crosssync_content_username'][$key]);
                        $passwords[] = wp_strip_all_tags($params['crosssync_content_password'][$key]);
                    }

                    $params['crosssync_host_name'] = $hostnames;
                    $params['crosssync_content_username'] = $usernames;
                    $params['crosssync_content_password'] = $passwords;
                }

                update_option('crosssync_setting', $params);

                $_SESSION['crosssync_msg_status'] = true;
                $_SESSION['crosssync_msg'] = 'Settings updated successfully.';
            }
        }

        function crosssync_get_settings_func()
        {
            $ncm_default_general_option = $this->crosssync_default_setting_option();
            $ncm_setting_option = get_option('crosssync_setting');
            return shortcode_atts($ncm_default_general_option, $ncm_setting_option);
        }

        function crosssync_get_admin_users($all_user = false, $fields = 'ID')
        {
            global $wpdb;
            $args = array(
                'role'         => 'Administrator',
                'orderby'      => 'ID',
                'order'        => 'ASC',
                'fields'       => $fields
            );
            $users = get_users($args);
            if ($all_user) {
                return $users;
            } else {
                return $users[0];
            }
        }

        function crosssync_get_post_types()
        {
            $all_types = get_post_types();
            $unset_keys = array('attachment', 'revision', 'nav_menu_item', 'custom_css', 'customize_changeset', 'oembed_cache', 'user_request', 'wp_block');

            foreach ($unset_keys as $uvalue) {
                if (isset($all_types[$uvalue])) {
                    unset($all_types[$uvalue]);
                }
            }
            return $all_types;
        }
    }

    global $crosssync_settings;
    $crosssync_settings = new crosssync_Settings();
}
